@@ -12,4 +12,6 @@ if nef_app.app:
 
     # import of specific importers must be after app creation to avoid circular imports
     import nef_pipelines.tools.fit.exponential  # noqa: F401
+    import nef_pipelines.tools.fit.mean  # noqa: F401
     import nef_pipelines.tools.fit.ratio  # noqa: F401
+    import nef_pipelines.tools.fit.t1noe  # noqa: F401
