@@ -50,6 +50,12 @@ def list(
         count=True,
         help="print verbose information more verbose options give more information",
     ),
+    write_error: bool = typer.Option(
+        False, "--write-error", help="write output to stderr"
+    ),
+    one_per_line: bool = typer.Option(
+        False, "-1", "--one-per-line", help="write frame names one per line"
+    ),
     filters: Optional[List[str]] = typer.Argument(
         None, help="filters string for entry names and categories to list"
     ),
@@ -93,16 +99,20 @@ def list(
             exit_error("couldn't read a nef stream from stdin")
 
     lines = str(entry)
-    with contextlib.redirect_stdout(sys.stderr):
-        print(f"entry {entry.entry_id}")
-        if verbose:
+    output_file = sys.stderr if write_error else sys.stdout
+    with contextlib.redirect_stdout(output_file):
+
+        if verbose > 0:
 
             import hashlib
 
+            print(f"entry {entry.entry_id}")
+            print()
+
             md5 = hashlib.md5(lines.encode("ascii")).hexdigest()
             num_lines = len(lines.split("\n"))
-            print(f"    lines: {num_lines} frames: {len(entry)} checksum: {md5} [md5]")
-        print()
+            print(f"lines: {num_lines} frames: {len(entry)} checksum: {md5} [md5]")
+            print()
 
         frames = select_frames(entry, filters, selector_type)
 
@@ -114,7 +124,15 @@ def list(
                     for i, frame_name in enumerate(frame_names, start=1)
                 ]
 
-            frame_list = strings_to_table_terminal_sensitive(frame_names)
+            if one_per_line:
+                frame_list = [
+                    [
+                        frame_name,
+                    ]
+                    for frame_name in frame_names
+                ]
+            else:
+                frame_list = strings_to_table_terminal_sensitive(frame_names)
             print(tabulate(frame_list, tablefmt="plain"))
 
         else:
