@@ -3,6 +3,7 @@ import sys
 from collections import Counter
 from enum import IntEnum, auto
 from pathlib import Path
+from textwrap import dedent
 from typing import Dict, List, Tuple, Union
 
 import typer
@@ -28,6 +29,7 @@ from nef_pipelines.lib.util import (
     is_int,
     parse_comma_separated_options,
     strings_to_tabulated_terminal_sensitive,
+    warn,
 )
 from nef_pipelines.tools.series import series_app
 
@@ -46,6 +48,7 @@ class RelaxationExperimentType(StrEnum):
     H_EXCHANGE_PROTECTION_FACTORS = auto()
     H_EXCHANGE_RATES = auto()
     HOMONUCLEAR_NOES = auto()
+    HETRONUCLEAR_T1_NOE = auto()
     CPMG = auto()
     CEST = auto()
     OTHER = auto()
@@ -63,6 +66,7 @@ EXPERIMENT_TYPE_TO_SERIES_VARIABLE_TYPE = {
     RelaxationExperimentType.HETERONUCLEAR_R1RHO_RELAXATION: "time",
     RelaxationExperimentType.HETERONUCLEAR_R1_RELAXATION: "time",
     RelaxationExperimentType.HETERONUCLEAR_R2_RELAXATION: "time",
+    RelaxationExperimentType.HETRONUCLEAR_T1_NOE: "time",
     RelaxationExperimentType.HETERONUCLEAR_NOES: "saturation",
     RelaxationExperimentType.CPMG: "cycles",
     RelaxationExperimentType.CEST: "offset",
@@ -75,6 +79,7 @@ EXPERIMENT_TYPE_TO_DATA_VARIABLE_TYPE = {
     RelaxationExperimentType.HETERONUCLEAR_R1RHO_RELAXATION: "intensity",
     RelaxationExperimentType.HETERONUCLEAR_R1_RELAXATION: "intensity",
     RelaxationExperimentType.HETERONUCLEAR_R2_RELAXATION: "intensity",
+    RelaxationExperimentType.HETRONUCLEAR_T1_NOE: "intensity",
     RelaxationExperimentType.HETERONUCLEAR_NOES: "intensity",
     RelaxationExperimentType.CPMG: "intensity",
     RelaxationExperimentType.CEST: "intensity",
@@ -169,7 +174,7 @@ def build(
     ),
     experiment_type: str = typer.Option(None, help="the type of the experiment"),
     display_parsed_values: bool = typer.Option(False, help="display the parsed values"),
-    frames_selectors: List[str] = typer.Argument(
+    frame_selectors: List[str] = typer.Argument(
         None,
         help=FRAMES_AND_TIMES_HELP,
     ),
@@ -178,25 +183,45 @@ def build(
 
     entry = read_entry_from_file_or_stdin_or_exit_error(input)
 
-    frame_selectors = parse_comma_separated_options(frames_selectors)
+    frame_selectors = parse_comma_separated_options(frame_selectors)
 
     _exit_if_no_frame_selectors(frame_selectors)
 
-    frames = _select_relaxation_frames(entry, frames_selectors)
-
-    frame_timings_and_units = _get_timings_and_units_for_frames(
-        frames, frame_selectors, timings, input_unit, display_parsed_values
+    frames_by_selector = _select_relaxation_frames_by_selector_or_exit_if_other(
+        entry, frame_selectors
     )
 
-    frames_and_timings, unit = (
-        _ensure_units_consistent_and_get_unit_and_timings_or_exit(
-            frame_timings_and_units
+    frame_timings_and_units_by_selector = {}
+    for selector, frames in frames_by_selector.items():
+        frame_timings_and_units_by_selector[selector] = (
+            _get_timings_and_units_for_frames(
+                frames,
+                [
+                    selector,
+                ],
+                timings,
+                input_unit,
+                display_parsed_values,
+            )
         )
-    )
 
-    # TODO arenn't these the same? add a name and expt attribute to the template and only use this notherwise
+    for (
+        selector,
+        frame_timings_and_units,
+    ) in frame_timings_and_units_by_selector.items():
+        frames_and_timings, unit = (
+            _ensure_units_consistent_and_get_unit_and_timings_or_exit(
+                frame_timings_and_units
+            )
+        )
+
+    frames_and_timings = {}
+    for frame_timings_and_units in frame_timings_and_units_by_selector.values():
+        frames_and_timings.update(frame_timings_and_units)
+
+    # TODO aren't these the same? add a name and expt attribute to the template and only use this notherwise
     if not name:
-        name = _guess_series_name(entry, frames_and_timings)
+        name = _make_series_name(entry, frames_and_timings)
 
     if not experiment_type:
         experiment_type = _guess_experiment_type(name)
@@ -216,25 +241,39 @@ def pipe(
 
     series_frame = create_nef_save_frame(f"{NEF_PIPELINES_NAMESPACE}_series_list", name)
 
-    series_variable_type = EXPERIMENT_TYPE_TO_SERIES_VARIABLE_TYPE[
-        RelaxationExperimentType[experiment_type]
-    ]
-    series_variable_unit = SERIES_VARIABLE_TYPE_TO_SERIES_VARIABLE_UNIT[
-        series_variable_type
-    ]
+    if experiment_type == "unknown":
+        series_variable_type = "unknown"
+    else:
+        series_variable_type = EXPERIMENT_TYPE_TO_SERIES_VARIABLE_TYPE[
+            RelaxationExperimentType[experiment_type]
+        ]
+
+    if series_variable_type == "unknown":
+        series_variable_unit = "unknown"
+    else:
+
+        series_variable_unit = SERIES_VARIABLE_TYPE_TO_SERIES_VARIABLE_UNIT[
+            series_variable_type
+        ]
 
     series_variable_unit = (
         unit if unit != series_variable_unit else series_variable_unit
     )
 
-    data_value_type = EXPERIMENT_TYPE_TO_DATA_VARIABLE_TYPE[
-        RelaxationExperimentType[experiment_type]
-    ]
+    if experiment_type == "unknown":
+        data_value_type = "unknown"
+    else:
+        data_value_type = EXPERIMENT_TYPE_TO_DATA_VARIABLE_TYPE[
+            RelaxationExperimentType[experiment_type]
+        ]
     data_value_unit = DATA_VARIABLE_TYPE_TO_DATA_VARIABLE_UNIT[data_value_type]
 
-    experiment_type = EXPERIMENT_TO_IDENTIFIER[
-        RelaxationExperimentType[experiment_type]
-    ]
+    if experiment_type == "unknown":
+        experiment_type = RelaxationExperimentType.OTHER
+    else:
+        experiment_type = EXPERIMENT_TO_IDENTIFIER[
+            RelaxationExperimentType[experiment_type]
+        ]
     tags = [
         ("experiment_type", experiment_type),
         ("series_variable_type", series_variable_type),
@@ -243,18 +282,21 @@ def pipe(
         ("data_variable_unit", series_variable_unit),
         ("data_value_type", data_value_type),
         ("data_value_unit", data_value_unit),
+        (
+            "version",
+            NEF_RELAXATION_VERSION,
+        ),
         ("comment", UNUSED),
     ]
     series_frame.add_tags(tags)
 
-    # TODO: pynmstar doesn't catch prepended spaces here it just gives and obscure error report!
+    # TODO: pynmstar doesn't catch prepended spaces here it just gives an obscure error report!
     series_experiment_loop = Loop.from_scratch(
         f"{NEF_PIPELINES_NAMESPACE}_series_experiment"
     )
     series_frame.add_loop(series_experiment_loop)
     series_experiment_loop.add_tag(
         [
-            "version",
             "nmr_spectrum_id",
             "reference_experiment",
             "combination_id",
@@ -266,11 +308,13 @@ def pipe(
     )
 
     loop_data = []
-    for frame_key, value in frame_timings.items():
+    for frame_key, (value, unit) in frame_timings.items():
         frame_name, _ = frame_key
+
+        value = _scale_value_by_unit(value, unit)
+
         loop_data.append(
             {
-                "version": NEF_RELAXATION_VERSION,
                 "nmr_spectrum_id": frame_name,
                 "reference_experiment": "false",
                 "combination_id": UNUSED,
@@ -296,7 +340,7 @@ def pipe(
 def _guess_experiment_type(name):
     upper_name = name.upper()
     for experiment_name in NAME_TO_EXPERIMENT_TYPE:
-        if experiment_name in upper_name:
+        if experiment_name in upper_name and upper_name in NAME_TO_EXPERIMENT_TYPE:
             result = NAME_TO_EXPERIMENT_TYPE[upper_name]
             break
         else:
@@ -304,7 +348,7 @@ def _guess_experiment_type(name):
     return result
 
 
-def _guess_series_name(entry, frames_and_timings):
+def _make_series_name(entry, frames_and_timings):
     result = None
     for relaxation_type in NAME_TO_EXPERIMENT_TYPE:
         do_break = False
@@ -415,17 +459,46 @@ def _exit_error_it_number_of_timings_doesnt_match_number_of_frames(
 
 
 def _exit_if_frame_selector_has_no_timing_selector(frame_selectors):
-    if len(frame_selectors) != 1 or "{var}" not in frame_selectors[0]:
-        NEWLINE = "\n"
-        msg = f"""
-                    no timings provided to select timings you must have a single frame selector with
-                    a {{var}} placeholder i got {len(frame_selectors)} frame selectors and they were:
-                    {NEWLINE.join(frame_selectors)}
-                """
+
+    reason = None
+
+    if (len(frame_selectors)) < 1:
+        reason = "no frames were selected"
+    else:
+        for i, frame_selector in enumerate(frame_selectors, start=1):
+            if "{var}" not in frame_selector:
+                reason = f"frame selector {i}: {frame_selector} doesn't contain a {{var}} place holder"
+
+    if reason:
+        msg = f"""\
+            timings not parsed because:
+
+            {reason}
+
+            to select timings you must have one or more frame selector each with
+            a {{var}} placeholder. I got {len(frame_selectors)} frame selectors and they were:
+
+            """
+        msg = dedent(msg)
+        frame_elector_strings = "\n".join(frame_selectors)
+        msg += frame_elector_strings
         exit_error(msg)
 
 
-def _select_relaxation_frames(entry: Entry, frame_selectors: List[str]) -> List[str]:
+def _select_relaxation_frames_by_selector_or_exit_if_other(
+    entry: Entry, frame_selectors: List[str]
+) -> List[Saveframe]:
+    """Select relaxation frames that are also spectrum frames using multiple selectors.
+
+    Args:
+        entry: NEF entry to search in
+        frame_selectors: List of frame frame_selector patterns
+
+    Returns:
+        List of spectrum frames that match the selectors (no duplicates)
+    """
+
+    # Get all spectrum frames
     spectrum_frames = select_frames(entry, "nef_nmr_spectrum", SelectionType.CATEGORY)
     spectrum_frame_ids = OrderedSet(
         [
@@ -434,36 +507,60 @@ def _select_relaxation_frames(entry: Entry, frame_selectors: List[str]) -> List[
         ]
     )
 
-    frame_selectors = [selector.replace("{var}", "*") for selector in frame_selectors]
-    frame_selectors = [selector.replace("{}", "*") for selector in frame_selectors]
-
-    relaxation_frames = []
+    # Process selectors with variable substitution and rememebr originals
+    processed_selectors_and_original_selectors = {}
     for frame_selector in frame_selectors:
-        relaxation_frames.extend(
-            select_frames(entry, frame_selector, SelectionType.NAME)
+
+        processed_selector = frame_selector.replace("{var}", "*").replace("{}", "*")
+        processed_selectors_and_original_selectors[processed_selector] = frame_selector
+
+    # Collect all frames matching any frame_selector (use OrderedSet to avoid duplicates)
+    frame_ids_by_selector = {}
+    for (
+        processed_frame_selector,
+        frame_selector,
+    ) in processed_selectors_and_original_selectors.items():
+        selected_frame_ids = OrderedSet()
+        frame_ids_by_selector[frame_selector] = selected_frame_ids
+
+        matching_frames = select_frames(
+            entry, processed_frame_selector, SelectionType.NAME
+        )
+        for frame in matching_frames:
+            selected_frame_ids.add((frame.name, id(frame)))
+
+    # Filter to only include spectrum frames (intersection)
+    for frame_selector, selected_frame_ids in frame_ids_by_selector.items():
+        frame_ids_by_selector[frame_selector] = spectrum_frame_ids.intersection(
+            selected_frame_ids
         )
 
-    relaxation_frame_ids = OrderedSet(
-        [
-            (relaxation_frame.name, id(relaxation_frame))
-            for relaxation_frame in relaxation_frames
+    # Check for non-spectrum frames and error if found (preserve original behavior)
+    for frame_selector, valid_frame_ids in frame_ids_by_selector.items():
+        non_spectrum_frame_ids = frame_ids_by_selector[frame_selector].difference(
+            valid_frame_ids
+        )
+        if non_spectrum_frame_ids:
+            non_spectrum_frame_names = "\n".join(
+                [frame_name for frame_name, _ in non_spectrum_frame_ids]
+            )
+            _exit_if_some_frames_are_not_spectra(
+                frame_selector, non_spectrum_frame_names
+            )
+
+    # Convert back to frame objects
+    valid_frames_by_selector = {}
+    for frame_selector, valid_frame_ids in frame_ids_by_selector.items():
+        valid_frames_by_selector[frame_selector] = [
+            entry.get_saveframe_by_name(frame_name) for frame_name, _ in valid_frame_ids
         ]
-    )
 
-    # TODO: just do an intersection dummy!
-    if not relaxation_frame_ids.issubset(spectrum_frame_ids):
-        non_spectrum_frames = relaxation_frame_ids.difference(spectrum_frame_ids)
-        non_spectrum_frame_names = "\n".join(
-            [non_spectrum_frame[0] for non_spectrum_frame in non_spectrum_frames]
-        )
-        # TODO: just filter out non spectra frames...
-        _exit_if_some_frames_are_not_spectra(non_spectrum_frame_names)
-
-    return relaxation_frames
+    return valid_frames_by_selector
 
 
-def _exit_if_some_frames_are_not_spectra(non_spectrum_frame_names):
+def _exit_if_some_frames_are_not_spectra(frame_selector, non_spectrum_frame_names):
     msg = f"""
+            using the frame selector {frame_selector}
             some of the selected frames are not spectrum frames:
             {non_spectrum_frame_names}
             """
@@ -471,8 +568,11 @@ def _exit_if_some_frames_are_not_spectra(non_spectrum_frame_names):
 
 
 def _parse_timings_from_frames_or_exit(
-    save_frames: List[Saveframe], frame_selector: str, display_parsed_values: bool
+    save_frames: Dict[Tuple[str, int], List[Saveframe]],
+    frame_selector: str,
+    display_parsed_values: bool,
 ) -> Dict[Tuple[str, int], List[Tuple[Union[int, float, bool], str]]]:
+
     if "{var}" not in frame_selector:
         msg = f"no timing selector placeholder {{var}} provided in frame selector {frame_selector}"
         exit_error(msg)
@@ -550,6 +650,7 @@ def _parse_value_and_unit(value: str) -> Tuple[Union[bool, int, float, None]]:
             value = int(value)
         elif is_float(value):
             value = float(value)
+        unit = ""
     else:
         unit = None
         value = None
@@ -642,3 +743,20 @@ def _exit_if_units_are_not_compatible(frame_timings_and_units):
                 {strings_to_tabulated_terminal_sensitive(units_and_timings_strings)}
                 """
         exit_error(msg)
+
+
+def _scale_value_by_unit(value, unit):
+    if is_float(value):
+        value = float(value)
+    if not unit or unit == "bool":
+        pass
+    elif unit.lower() in ("us", "ms"):
+        if unit.lower() == "ms":
+            value *= 1e-3
+        elif unit.lower() == "us":
+            value *= 1e-6
+    else:
+        msg = f""" scaling by unit {unit} not implemented [value: {value}], ignoring!"""
+        warn(msg)
+
+    return round(value, 6)
