@@ -135,6 +135,18 @@ def shifts(
         print(entry)
 
 
+def _assigned_shifts_filter_non_numeric_sequence_codes(assigned_shifts):
+    new_assigned_shifts = set()
+
+    for assigned_shift in assigned_shifts:
+        if not is_int(assigned_shift.atom.residue.sequence_code):
+            continue
+        else:
+            new_assigned_shifts.add(assigned_shift)
+
+    return new_assigned_shifts
+
+
 def pipe(
     entry: Entry,
     shift_frame_selectors: List[str],
@@ -154,6 +166,9 @@ def pipe(
 
     # TODO: filter shifts which have odd assignments
     # TODO: issue a warning if there are shifts which are not defined
+    assigned_shifts = _assigned_shifts_filter_non_numeric_sequence_codes(
+        assigned_shifts
+    )
 
     shift_chains = shifts_to_chains([*assigned_shifts, *unassigned_shifts])
 
@@ -277,7 +292,7 @@ def _exit_on_sequence_and_shift_residue_name_mismatch(shifts, residue_name_looku
             frame_headers[0] = f"#{frame_headers[0]}"
             line_info = tabulate([frame_headers, frame_row], tablefmt="plain")
             msg = f"""
-                    error for atom {shift.atom.name} in chain {shift.atom.residue.chain_code}
+                    error for atom {shift.atom.atom_name} in chain {shift.atom.residue.chain_code}
                     the residue type in the sequence doesn't match residue type in shifts
 
                     sequence residue name {sequence_residue_name}
