@@ -9,7 +9,6 @@ import hjson
 import typer
 from fyeah import f
 from lazy_import import lazy_module
-from ordered_set import OrderedSet
 from pynmrstar import Entry
 from tabulate import tabulate
 
@@ -18,7 +17,7 @@ from nef_pipelines.lib.nef_lib import (
     add_frames_to_entry,
     loop_row_namespace_iter,
     read_entry_from_file_or_exit_error,
-    read_entry_from_file_or_stdin_or_exit_error,
+    read_or_create_entry_exit_error_on_bad_file,
 )
 from nef_pipelines.lib.sequence_lib import (
     get_chain_code_iter,
@@ -31,6 +30,7 @@ from nef_pipelines.lib.util import (
     chunks,
     exit_error,
     flatten,
+    is_int,
     nef_pipelines_root,
     parse_comma_separated_options,
 )
@@ -55,6 +55,15 @@ STEREO_HELP = """\
     - auto: use as assigned if some geminal stereo assignments are present, otherwise assume all are ambiguous
 """
 
+FRAME_NAME_HELP = """\
+a name for the frame, the default is default. If you want to use the id of the nmrstar entry you can use a template
+which includes {entry_id} to also add the name of the shift frame use {indentifier}
+e.g. bmr{entry_id}__{identifier} with an entry id of 1234  and and identifier of shift_list_1
+would give bmr1234__shift_list_1
+use double brace to escape the templates e.g. bmr{{entry_id}}__{{identifier}} woudl give
+bmr{entry_id}__{identifier}
+"""
+
 
 @import_app.command()
 def shifts(
@@ -64,16 +73,13 @@ def shifts(
         help="chain codes as a list of names separated by commas, repeated calls will add further chains [default A]",
         metavar="<CHAIN-CODES>",
     ),
-    frame_name: str = typer.Option(
-        None,
-        "-f",
-        "--frame-name",
-        help="a name for the frame, default is the name nmrstar entry",
+    frame_name_template: str = typer.Option(
+        None, "-f", "--frame-name", help=FRAME_NAME_HELP
     ),
     input: Path = typer.Option(
         STDIN,
         "-i",
-        "--input",
+        "--in",
         metavar="|PIPE|",
         help="file to read NEF data from [- is stdin; defaults is stdin]]",
     ),
@@ -81,6 +87,9 @@ def shifts(
     use_author: bool = typer.Option(
         False, help="use author fields for chain_code, sequence_code and residue_name"
     ),
+    entry_name: str = typer.Option(
+        "nmrpipe", "-e", "--entry", help="entry name", metavar="<entry-name>"
+    ),
     file_path: Path = typer.Argument(
         ..., help="input files of type shifts.txt", metavar="<NMR-STAR-shifts>.str"
     ),
@@ -91,12 +100,14 @@ def shifts(
 
     chain_codes = parse_comma_separated_options(chain_codes)
 
-    nef_entry = read_entry_from_file_or_stdin_or_exit_error(input)
+    nef_entry = read_or_create_entry_exit_error_on_bad_file(
+        input, entry_name=entry_name
+    )
 
     nef_entry = pipe(
         nef_entry,
         chain_codes,
-        frame_name,
+        frame_name_template,
         nmrstar_entry,
         file_path,
         use_author,
@@ -109,7 +120,7 @@ def shifts(
 def pipe(
     nef_entry: Entry,
     chain_codes: List[str],
-    frame_name: str,
+    frame_name_template: str,
     nmrstar_entry: Entry,
     file_name: Path,
     use_author: bool,
@@ -131,12 +142,12 @@ def pipe(
 
     stereo_mode = _get_stereo_mode(ambiguities, stereo_mode)
 
-    entity_id_to_chain_code = _build_entity_ids_to_chain_codes(
-        chain_codes, denormalised_shifts
+    entity_ids_to_chain_codes = _build_entity_ids_to_chain_codes(
+        nmrstar_entry, chain_codes
     )
 
     denormalised_shifts = _replace_shift_entity_ids_with_chain_codes(
-        denormalised_shifts, entity_id_to_chain_code
+        denormalised_shifts, entity_ids_to_chain_codes
     )
 
     per_residue_and_atom_shifts = _organise_shifts_by_residue_and_atom_names(
@@ -152,7 +163,7 @@ def pipe(
     )
 
     ambiguities = _replace_atom_dict_entity_ids_with_chain_codes(
-        ambiguities, entity_id_to_chain_code
+        ambiguities, entity_ids_to_chain_codes
     )
 
     per_residue_ambiguities = _organise_ambiguities_by_residue(ambiguities)
@@ -182,8 +193,15 @@ def pipe(
         )
     )
 
-    if not frame_name:
-        frame_name = name_info.entry_id + "__" + str(name_info.identifier)
+    if frame_name_template:
+        if "{entry_id}" in frame_name_template or "{identifier}" in frame_name_template:
+            frame_name = frame_name_template.format(
+                entry_id=name_info.entry_id, identifier=name_info.identifier
+            )
+        else:
+            frame_name = frame_name_template
+    else:
+        frame_name = "default"
 
     shifts_frame = shifts_to_nef_frame(ShiftList(all_shifts), frame_name)
 
@@ -568,9 +586,8 @@ def _chemical_shifts_from_star_frame(nmrstar_entry, use_author, file_name):
     denormalised_shifts = []
 
     frame_code = shift_lists[0].get_tag("Sf_framecode")[0]
-    category = shift_lists[0].get_tag("Sf_category")[0]
     entry_id = shift_lists[0].get_tag("Entry_ID")[0]
-    list_identifier = frame_code[len(category) + 1 :].lstrip("_")
+    list_identifier = frame_code.lstrip("_")
     name_info = ShiftListNameInfo(entry_id, list_identifier)
 
     for i, shift_list in enumerate(shift_lists):
@@ -595,8 +612,10 @@ def _chemical_shifts_from_star_frame(nmrstar_entry, use_author, file_name):
                 comp_id = row.Auth_comp_ID
             else:
                 atom_id = row.Atom_ID
-                seq_id = row.Seq_ID
+                seq_id = row.Seq_ID if hasattr(row, "Seq_ID") else None
                 comp_id = row.Comp_ID
+                if not seq_id and hasattr(row, "Comp_index_ID"):
+                    seq_id = row.Comp_index_ID
 
             if atom_id == UNUSED and use_author:
                 atom_id = row.Atom_ID
@@ -607,9 +626,9 @@ def _chemical_shifts_from_star_frame(nmrstar_entry, use_author, file_name):
 
             shift = row.Val
             sdev = row.Val_err
-            element = row.Atom_type
+            element = row.Atom_type if hasattr(row, "Atom_type") else None
             isotope = row.Atom_isotope_number
-            ambiguity_code = row.Ambiguity_code
+            ambiguity_code = row.Ambiguity_code if hasattr(row, "Ambiguity_code") else 1
 
             residue = Residue(chain_code, seq_id, comp_id)
             atom = AtomLabel(residue, atom_id, element, isotope)
@@ -683,18 +702,23 @@ def _replace_atom_dict_entity_ids_with_chain_codes(
     return result
 
 
-def _build_entity_ids_to_chain_codes(chain_codes, denormalised_shifts):
-    entity_ids = list(
-        OrderedSet(
-            sorted([shift.atom.residue.chain_code for shift in denormalised_shifts])
+def _build_entity_ids_to_chain_codes(nmrstar_entry, chain_codes):
+    entity_saveframes = nmrstar_entry.get_saveframes_by_category("entity")
+
+    result = {
+        entity_saveframe.get_tag("ID")[0]: chain_code
+        for entity_saveframe, chain_code in zip(
+            entity_saveframes, get_chain_code_iter(chain_codes)
         )
-    )
-    chain_code_iter = get_chain_code_iter(chain_codes)
-    entity_id_to_chain_code = {
-        entity_id: chain_code
-        for entity_id, chain_code in zip(entity_ids, chain_code_iter)
     }
-    return entity_id_to_chain_code
+
+    # things that look like ints are getting converted to ints on input
+    result = {
+        int(entity_id) if is_int(entity_id) else entity_id: chain_code
+        for entity_id, chain_code in result.items()
+    }
+
+    return result
 
 
 def _exit_error_if_missing_residues(residues, shift_residues, file_name):
