@@ -2,10 +2,11 @@ import os
 import re
 import sys
 import tempfile
+import time
 from dataclasses import dataclass
 from enum import Enum, auto
 from pathlib import Path
-from textwrap import dedent
+from textwrap import dedent, indent
 from typing import Optional
 from urllib.parse import urlsplit
 
@@ -40,6 +41,7 @@ ALPHA_FOLD_URL_TEMPLATE = (
 )
 
 SHIFTX2_RETRY_COUNT = 10
+DEFAULT_TIMEOUT = 2
 
 
 @dataclass
@@ -138,7 +140,15 @@ def shifts(
     ),
 ):
     """- read a shiftx2 chemical shift prediction [alpha]"""
+
+    if not source_chain:
+        source_chain = "A"
+
+    if not chain:
+        chain = source_chain
+
     entry = read_or_create_entry_exit_error_on_bad_file(in_file, "shiftx2")
+
     entry = pipe(entry, code_or_file_name, source_chain, chain, alphafold, verbose)
     print(entry)
 
@@ -152,6 +162,9 @@ def pipe(
     verbose: bool,
 ) -> Entry:
 
+    if not chain and source_chain:
+        chain = source_chain
+
     file_path = Path(code_or_filename)
     if file_path.exists():
         shifts = _read_shifts_from_file(file_path, chain)
@@ -166,17 +179,25 @@ def pipe(
         else:
             use_file = False
 
-        if not chain and source_chain:
-            chain = source_chain
-
+        timeout = DEFAULT_TIMEOUT
         for i in range(1, SHIFTX2_RETRY_COUNT + 1):
-            shifts = _get_shifts_from_server(
+            shifts, request = _get_shifts_from_server(
                 code_or_filename, source_chain, chain, use_file=use_file
             )
+            time.sleep(timeout)
             if shifts:
                 break
             elif verbose:
-                print(f"retrying shiftx2 ...[{i}]", file=sys.stderr)
+                _note_if_bad_html_request(code_or_filename, request)
+                _note_if_error_calculating_shifts(code_or_filename, request)
+                _warn(f"retrying shiftx2 ...[{i}]")
+            if "server" in request.text.lower() and "busy" in request.text.lower():
+                old_timeout = timeout
+                timeout = _increment_timeout(timeout)
+                if verbose:
+                    _warn(
+                        f"timeout too short increase timeout from {old_timeout}s -> {timeout}"
+                    )
 
         _exit_if_too_many_attempted_connections(
             shifts, code_or_filename, SHIFTX2_RETRY_COUNT
@@ -233,12 +254,20 @@ def pipe(
     return entry
 
 
+def _increment_timeout(timeout):
+    if timeout == 0:
+        timeout = 1
+    else:
+        timeout = timeout * 2
+    return timeout
+
+
 def _exit_if_too_many_attempted_connections(shifts, code_or_filename, RETRY_COUNT):
     if not shifts:
-        msg = f"""
+        msg = f"""\
             couldn't get a shiftx2 prediction for {code_or_filename} after {RETRY_COUNT} retries
             """
-        exit_error(msg)
+        exit_error(msg.strip())
 
 
 class ShiftFormat(Enum):
@@ -441,19 +470,15 @@ def _get_shifts_from_server(
         data["pdbid"] = pdb_file_or_code
 
     if use_file:
-        r = requests.request("POST", CGI_URL, data=data, files=files)
+        request = requests.request("POST", CGI_URL, data=data, files=files)
 
     else:
-        r = requests.request("POST", CGI_URL, data=data)
+        request = requests.request("POST", CGI_URL, data=data)
 
     if fh:
         fh.close()
 
-    _exit_if_bad_html_request(pdb_file_or_code, r)
-
-    _exit_if_error_calculating_shifts(pdb_file_or_code, r)
-
-    soup = BeautifulSoup(r.text, features="html.parser")
+    soup = BeautifulSoup(request.text, features="html.parser")
     shifts = ""
     putative_links = soup.find_all("a", href=True, string="download predictions")
     if putative_links:
@@ -464,35 +489,51 @@ def _get_shifts_from_server(
 
         shifts = _parse_text_to_shifts(text, cli_chain_code, CGI_URL)
 
-    return shifts
+    return shifts, request
 
 
-def _exit_if_bad_html_request(pdb_code, r):
-    if r.status_code != 200:
-        msg = f"""
+def _warn(msg):
+    msg = dedent(msg)
+    msg = f"WARNING: {msg}"
+    msg = indent(msg, "   ")
+    print(msg, file=sys.stderr)
+
+
+def _note(msg, verbose):
+
+    if verbose:
+        msg = f"NOTE: {msg}"
+        out_file = sys.stderr
+        msg = dedent(msg)
+        print(msg, file=out_file)
+
+
+def _note_if_bad_html_request(pdb_code, request):
+    if request.status_code != 200:
+        msg = f"""\
         failed to download shifts from {CGI_URL} for pdb code {pdb_code}
         is you network connection working?
         """
-        exit_error(msg)
+        _warn(msg)
 
 
-def _exit_if_error_calculating_shifts(pdb_code, r):
+def _note_if_error_calculating_shifts(pdb_code, request):
 
-    if "Error in Calculating Chemical Shifts" in r.text:
-        soup = BeautifulSoup(r.text, features="html.parser")
+    if "Error" in request.text:
+        soup = BeautifulSoup(request.text, features="html.parser")
         texts = soup.findAll(string=True)
         visible_texts = filter(tag_visible, texts)
         text = " ".join(t.strip() for t in visible_texts)
         text = _spaces_to_single(text)
         text = _dedent_all(text)
         text = _select_text_between(text, "SHIFTX2 PREDICTIONS", "Please try again")
-        msg = f"""
+        msg = f"""\
         failed to calculate shifts from {CGI_URL} for pdb code {pdb_code}
         the msg was:
 
-        {text}
+       {text}
         """
-        exit_error(msg)
+        _warn(msg)
 
 
 def _exit_if_pdb_code_bad(pdb_code):
@@ -574,35 +615,39 @@ def _exit_if_pdb_download_bad(pdb_file_data: PDBDownloadResult):
 
 
 def _pdb_code_to_alphafold_pdb_file(code_or_filename, source_chain, verbose):
-    msg = [f"# alphafold: {code_or_filename}->"]
 
     mapping = _convert_pdb_code_to_uniprot_id(code_or_filename, source_chain)
 
     _exit_if_pdb_to_uniprot_network_failure(mapping)
-    _exit_if_pdb_to_uniprot_mapping_fails(mapping)
-
-    msg.append(f"{mapping.uniprot_id}->")
+    _exit_if_pdb_to_uniprot_mapping_fails(code_or_filename, mapping)
 
     alphafold_result = _get_alphafold_pdb_url_from_uniprot_id(mapping)
 
     _exit_if_alphafold_network_bad(alphafold_result)
     _exit_if_alphafold_uniprot_to_pdb_url_fails(alphafold_result)
 
-    msg.append(alphafold_result.alphafold_id)
+    _note_uniprot_mapping_if_verbose(alphafold_result, verbose)
 
     pdb_file_data = _download_pdb_file(alphafold_result)
 
     _exit_if_pdb_download_bad(pdb_file_data)
 
-    # TODO: why does this corrupt a NEF stream i printed to stdout rather than stderr...
-    if verbose:
-        print(
-            "".join(msg),
-            f"[{ALPHA_FOLD_URL_TEMPLATE.format(uniprot_id=mapping.uniprot_id, alphafold_key=ALPHA_FOLD_KEY)}]",
-            file=sys.stderr,
+    return pdb_file_data
+
+
+def _note_uniprot_mapping_if_verbose(mapping, verbose):
+    if mapping:
+        pdb_start = mapping.pdb_start_residue
+        uniprot_start = mapping.pdb_uniprot_start
+        msg = (
+            f"uniprot mapping, pdb:{mapping.pdb_code}:{pdb_start} -> uniprot:{mapping.uniprot_id}:{uniprot_start}"
+            " ->  alphafold:{mapping.alphafold_id}:{uniprot_start}"
         )
 
-    return pdb_file_data
+        _note(msg, verbose)
+
+        if not verbose:
+            print(f"# shiftx2 {msg}")
 
 
 def _download_pdb_file(alphafold_result: AlphafoldResult) -> PDBDownloadResult:
@@ -705,7 +750,11 @@ def _convert_pdb_code_to_uniprot_id(
             "UniProt"
         ].items():
             for mapping in mapping_element["mappings"]:
-                if mapping["chain_id"] == source_chain:
+                if (
+                    mapping["chain_id"]
+                    and source_chain
+                    and (mapping["chain_id"].lower() == source_chain.lower())
+                ):
                     uniprot_id = putative_uniprot_id
                     break
 
@@ -749,7 +798,7 @@ def _exit_if_pdb_to_uniprot_network_failure(mapping: PdbUniprotMapping):
         exit_error(msg)
 
 
-def _exit_if_pdb_to_uniprot_mapping_fails(mapping: PdbUniprotMapping):
+def _exit_if_pdb_to_uniprot_mapping_fails(code, mapping: PdbUniprotMapping):
 
     if mapping.uniprot_id is None:
         mapping_table = []
@@ -782,8 +831,8 @@ def _exit_if_pdb_to_uniprot_mapping_fails(mapping: PdbUniprotMapping):
             """
         msg = dedent(msg)
         msg = msg.format(
-            code_or_filename=mapping.pdb_code.upper(),
-            source_chain=mapping.chain_code,
+            code_or_filename=code.upper(),
+            source_chain=mapping["chain_id"],
             mapping_table=mapping_table,
         )
         exit_error(msg)
